==> remmina_1.4.2+dfsg.orig.tar.xz: Remmina-v1.4.2/THANKS.md <==
### Donors

This is a list of donors, keeping at the top those that have donated more.
This is not to reduce the importance of smaller donations, as we all give what we can in accordance with our own resources.

### Top donations

- Daniel Bolter
- Rafael Wolf owner of [EITS, LLC, dba Express IT Solutions](https://eitsonline.com) Kalamazoo, MI 49048 USA. ( **Donated $100** )
- [Khalifa Alshamsi ](https://twitter.com/kha1ifa__)
- [Tim Richardson - GrowthPath founder](https://www.growthpath.com.au/people/growthpath-team-2)

### Year 2020 donors

- Абрамов Павел
- Peter Vollebregt

### Year 2019 donors

- Daniel Bolter
- Khalifa Alshamsi (https://twitter.com/kha1ifa__)
- Christian Houle
- Ingo Humann
- Justin Scott
- Luděk Habarta
- atzk
- Abdulkarim Khormi
- Андрей Коробков
- Andres Zanzani
- Andrew Hart
- Antonio Quinonez-Mun
- Balvas Eugene
- Benoit Mercier
- Blagoy Chepelov
- Clayton Casciato
- Clemens Eberwein
- Cordula Herzog
- Denis Đukić
- Dennis Lampe
- Denoid Tucker
- EXCOMEDIA, Inc.
- Герун Данил
- Graham Sivill
- Gunter Moegel
- Hawkins IT Group Inc
- Hector SAenz
- Исаков Андрей
- Janez Košmrlj
- Jonathan Rogers
- Josef Abdel Wahed
- Jürgen Müller
- Клюенков Алексей
- Lance Edusei
- Подловилин Виталий
- Lutz Urban
- Majed Zouhairy
- Manuel Moelgg
- Мантуров Дмитрий
- Marc Schlegel
- Marcel Pötter
- Marcel Ostrovsky
- Marcin Wolcendorf
- Marjan Bugarinović
- Marko Milosavljevic
- Markus Heimberg
- Marwan Yassin
- Matteo Biaggi
- Matthias Baumann
- Matthias Tapis
- Mathieu Morlon
- Michael Brazeau
- Márcio Oliveira Luiz
- Nils Panitzsch
- Per Arnold Blaasmo
- Petar Kulić
- Philipp Köhler
- Roman Cravtov
- Robert Premuž
- Ross Philip
- Ruston Rountree
- Sergio Omiccioli
- Thomas Stofer Computerservice
- Trond Nystuen
- Werner Mittermayer
- Welles Freire Ximenes
- Wolfgang Scherer

### Year 2018 donors

- Anton Karmanov
- Antonio Quinonez-Mun
- Clemens Anhuth
- CSI Dudek Marcin
- coder-zero @Future Systems bvba
- Debapriyo Sarkar
- Harjit Takshak
- Marco Polano
- Michael Hipp
- Peter Link
- Praveen Bhamidipati
- Radek Loutocký
- Richard Flathmann
- Sergey Lebfr
- Tommy Sweeney

### Year 2017 donors

- Anonymous (16)
- Brad Kulkin
- Daniel Platteau
- Dmitry Yudin
- Fuad kamal
- František Řezáč
- Jakub Kubień
- Leigh Mutimer
- Luca Menini
- Mauro Frischherz
- Paul Walker
- Tomasz Kubacki

### Year 2016 donors

These donors have contributed with an important amount of money during the year 2016

- Daniel Bolter
- Bruce Cran
- Jamison Guyton

These donors are listed in first name alphabetical order.

- Allen Smith
- Антонов Иван
- Artur Mroczko
- Bruce Cran
- Cesar Reza
- Christian Uceda
- Dietmar Wolf
- Gustavo Uceda
- Ivan Antonov
- Ivan Dobrianov
- Jamison Guyton
- Lars Povlsen
- Lynne Lawrence
- Mikhail Blinkov
- Michael Gruben
- Michael Schneider
- Nic Galler
- Patrick Saccani-Williams
- Paul Johnson
- Paul Zoulin
- Richard Lees
- Richard Pendlebury
- Stepan Naumov
- Tim Richardson
- Troy Lea
- Viktor Sik

Ask us at any time how donations are used, if you want more details added, or if you want your name removed.
Exact amounts are only disclosed upon request to protect privacy.

### Community

Without the  **Remmina community** of remminers, this project wouldn't exist.

### Core team

* Antenore Gatta ([antenore](https://github.com/antenore)) and **Giovanni Panozzo** ([giox069](https://github.com/giox069)) resurrected Remmina.
* Dario Cavedon ([DarioCavedon](https://plus.google.com/+DarioCavedon)), our "everything" counselor, writer, legal adviser and social media expert.

### Collaborators

* Dennis Ollier ([larchunix](https://github.com/larchunix)) made the SPICE protocol plugin.
* Luca Falavigna ([dktrkranz](https://github.com/dktrkranz)) Ubuntu PPA and Remmina patches.
* Matteo F. Vescovi ([mfvescovi](https://github.com/mfvescovi)) brought the Remmina upstream version to Debian and Ubuntu.
* Matteo Nastasi ([nastasi](https://github.com/nastasi)) started the implementation of build recipies for Ubuntu and Debian.
* Johannes Weberhofer ([weberhofer](https://github.com/weberhofer)) and **Pavel Alexeev** ([Hubbitus](https://github.com/Hubbitus))
* Fabio Castelli ([muflone](https://github.com/muflone)) great improvements and functionalities.

### Originators

**Marc-André Moreau** ([awakecoding](https://github.com/awakecoding)) and **Vic Lee** ([llyzs](https://github.com/llyzs)), we are deeply grateful you placed your
trust in us (Antenore & Giovanni) to represent Remmina.

The [FreeRDP](https://github.com/FreeRDP/FreeRDP) project, the most advanced and updated RDP library to date.

### The GNOME VTE project

Particularly **Egmont Koblinger** ([@egmontkob](https://github.com/egmontkob)) and **Christian Persch** for their support.

### Disclaimer

If we have forgot anybody or got something wrong, don't hesitate to contact us, or help fix it.

==> remmina_1.4.29+dfsg.orig.tar.xz: Remmina-v1.4.29/THANKS.md <==
### Donors

This is a list of donors, keeping at the top those that have donated more.
This is not to reduce the importance of smaller donations, as we all give what we can in accordance with our own resources.

### Top donations

- Daniel Bolter
- Rafael Wolf owner of [EITS, LLC, dba Express IT Solutions](https://eitsonline.com) Kalamazoo, MI 49048 USA. ( **Donated $100** )
- [Khalifa Alshamsi ](https://twitter.com/kha1ifa__)
- [Tim Richardson - GrowthPath founder](https://www.growthpath.com.au/people/growthpath-team-2)

### Year 2021 donors

- Bruno Gadaleta
- /u/esmpsu89
- Dark Star
- Vinz
- Andre Steinz
- Eric Taylor
- Incognito
- MARCELO
- L.Adigard
- Antoni Aloy Torrens
- Raphael Schweikert sabberworm 
- Marwan Yassin Marware 
- dpirly
- Brendan Long brendanlong
- Gabriel Einsdorf gab1one 
- Malcolm Smith mds08011
- Vektor Prime vektorprime 
- theschitz theschitz
- Matthew Mattox mattmattox 
- Yoann YoannMourot 

Coporates:
- Babiel GmbH

### Year 2020 donors

- Абрамов Павел
- Peter Vollebregt

### Year 2019 donors

- Daniel Bolter
- Khalifa Alshamsi (https://twitter.com/kha1ifa__)
- Christian Houle
- Ingo Humann
- Justin Scott
- Luděk Habarta
- atzk
- Abdulkarim Khormi
- Андрей Коробков
- Andres Zanzani
- Andrew Hart
- Antonio Quinonez-Mun
- Balvas Eugene
- Benoit Mercier
- Blagoy Chepelov
- Clayton Casciato
- Clemens Eberwein
- Cordula Herzog
- Denis Đukić
- Dennis Lampe
- Denoid Tucker
- EXCOMEDIA, Inc.
- Герун Данил
- Graham Sivill
- Gunter Moegel
- Hawkins IT Group Inc
- Hector SAenz
- Исаков Андрей
- Janez Košmrlj
- Jonathan Rogers
- Josef Abdel Wahed
- Jürgen Müller
- Клюенков Алексей
- Lance Edusei
- Подловилин Виталий
- Lutz Urban
- Majed Zouhairy
- Manuel Moelgg
- Мантуров Дмитрий
- Marc Schlegel
- Marcel Pötter
- Marcel Ostrovsky
- Marcin Wolcendorf
- Marjan Bugarinović
- Marko Milosavljevic
- Markus Heimberg
- Marwan Yassin
- Matteo Biaggi
- Matthias Baumann
- Matthias Tapis
- Mathieu Morlon
- Michael Brazeau
- Márcio Oliveira Luiz
- Nils Panitzsch
- Per Arnold Blaasmo
- Petar Kulić
- Philipp Köhler
- Roman Cravtov
- Robert Premuž
- Ross Philip
- Ruston Rountree
- Sergio Omiccioli
- Thomas Stofer Computerservice
- Trond Nystuen
- Werner Mittermayer
- Welles Freire Ximenes
- Wolfgang Scherer

### Year 2018 donors

- Anton Karmanov
- Antonio Quinonez-Mun
- Clemens Anhuth
- CSI Dudek Marcin
- coder-zero @Future Systems bvba
- Debapriyo Sarkar
- Harjit Takshak
- Marco Polano
- Michael Hipp
- Peter Link
- Praveen Bhamidipati
- Radek Loutocký
- Richard Flathmann
- Sergey Lebfr
- Tommy Sweeney

### Year 2017 donors

- Anonymous (16)
- Brad Kulkin
- Daniel Platteau
- Dmitry Yudin
- Fuad kamal
- František Řezáč
- Jakub Kubień
- Leigh Mutimer
- Luca Menini
- Mauro Frischherz
- Paul Walker
- Tomasz Kubacki

### Year 2016 donors

These donors have contributed with an important amount of money during the year 2016

- Daniel Bolter
- Bruce Cran
- Jamison Guyton

These donors are listed in first name alphabetical order.

- Allen Smith
- Антонов Иван
- Artur Mroczko
- Bruce Cran
- Cesar Reza
- Christian Uceda
- Dietmar Wolf
- Gustavo Uceda
- Ivan Antonov
- Ivan Dobrianov
- Jamison Guyton
- Lars Povlsen
- Lynne Lawrence
- Mikhail Blinkov
- Michael Gruben
- Michael Schneider
- Nic Galler
- Patrick Saccani-Williams
- Paul Johnson
- Paul Zoulin
- Richard Lees
- Richard Pendlebury
- Stepan Naumov
- Tim Richardson
- Troy Lea
- Viktor Sik

Ask us at any time how donations are used, if you want more details added, or if you want your name removed.
Exact amounts are only disclosed upon request to protect privacy.

### Community

Without the  **Remmina community** of remminers, this project wouldn't exist.

### Core team

* Antenore Gatta ([antenore](https://github.com/antenore)) and **Giovanni Panozzo** ([giox069](https://github.com/giox069)) resurrected Remmina.
* Dario Cavedon ([DarioCavedon](https://plus.google.com/+DarioCavedon)), our "everything" counselor, writer, legal adviser and social media expert.

### Collaborators

* Dennis Ollier ([larchunix](https://github.com/larchunix)) made the SPICE protocol plugin.
* Luca Falavigna ([dktrkranz](https://github.com/dktrkranz)) Ubuntu PPA and Remmina patches.
* Matteo F. Vescovi ([mfvescovi](https://github.com/mfvescovi)) brought the Remmina upstream version to Debian and Ubuntu.
* Matteo Nastasi ([nastasi](https://github.com/nastasi)) started the implementation of build recipies for Ubuntu and Debian.
* Johannes Weberhofer ([weberhofer](https://github.com/weberhofer)) and **Pavel Alexeev** ([Hubbitus](https://github.com/Hubbitus))
* Fabio Castelli ([muflone](https://github.com/muflone)) great improvements and functionalities.

### Originators

**Marc-André Moreau** ([awakecoding](https://github.com/awakecoding)) and **Vic Lee** ([llyzs](https://github.com/llyzs)), we are deeply grateful you placed your
trust in us (Antenore & Giovanni) to represent Remmina.

The [FreeRDP](https://github.com/FreeRDP/FreeRDP) project, the most advanced and updated RDP library to date.

### The GNOME VTE project

Particularly **Egmont Koblinger** ([@egmontkob](https://github.com/egmontkob)) and **Christian Persch** for their support.

### Disclaimer

If we have forgot anybody or got something wrong, don't hesitate to contact us, or help fix it.
